@@ -217,35 +217,10 @@ pub fn get_float_value (arg : Option<&Value>) -> &f64 {
 
 #[cfg(test)]
 mod tests {
-    use regex::Regex;
     #[test]
     fn hello_test (){
         println!("Hello");
 
-        // let re_str = Regex::new(":AAAA( |$)").unwrap();
-        // let re_str = Regex::new("(?i):aAAA( |$|\t|\r|\n)").unwrap();
-        let key = "AaAa";
-        let re_str = Regex::new(format!("(?i):{}( |$|\t|\r|\n)", key).as_str()).unwrap();
-        // let re_key = Regex::new(format!("(?i):{}( |$|\t|\r|\n)", key).as_str()).unwrap();
-        let re_key = Regex::new(format!("(?i):{}\\)", key).as_str()).unwrap();
-        let text = "EFEF AAAA :AAAA BBBB CCCC :AaaA)     DDDD :AAAAA BBB :AAAA2 :aaaa\n :aAaA";
-
-        let mut sql = String::from(text);
-
-        let m = "xxxx";
-
-        sql = re_key.replace_all(&sql, format!("'{}' ", m).as_str()).to_string();
-
-        println!("sql: {}", sql);
-        // println!("{}", re_str.replace_all(text, "'xxxx' "));
-
-        // for cap in re_str.captures_iter(text) {
-        //     println!("Found: {} ", &cap[0]);
-        // }
-
-        // if re_str.is_match(text) {
-        //     println!("true");
-        // }
 
 
     }
